Method: BaseCRM#custom_fields
- Defined in:
-
lib/basecrm/models/lead.rb,
lib/basecrm/models/contact.rb
Returns Custom fields are a key-value pair attached to a contact. See more at [Custom Fields](/docs/rest/articles/requests#custom_fields). Note! You need to set Filterable on from Settings -> Contacts to be able to search by custom fields.
|
|
# File 'lib/basecrm/models/lead.rb', line 18
|